Crate mdbookkit

Crate mdbookkit 

mdbookkit

Support library for mdBook preprocessors in the mdbookkit project.

You may be looking for:

[!NOTE]

This package previously provided preprocessor binaries. The preprocessors are now published as standalone packages. You should no longer install this package:

cargo uninstall mdbookkit
# cargo install mdbook-rustdoc-links
# cargo install mdbook-permalinks

Note that the names of the executables have been updated, so you will need to update your book.toml as well:

- [preprocessor.rustdoc-link]
+ [preprocessor.rustdoc-links]
- [preprocessor.link-forever]
+ [preprocessor.permalinks]

Modules

book
diagnostics
Error reporting for preprocessors.
env
error
logging
Logging facilities.
markdown
Markdown-related utilities.
url

Macros

emit_debug
emit_error
emit_trace
emit_warning
plural
ticker
ticker_event
ticker_item